@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Cwd;
 
-our $VERSION = '0.9021';
+our $VERSION = '0.9024';
 
 sub new {
     my($class, $file) = @_;
@@ -92,6 +92,7 @@ sub to_string {
             }
         }
 
+        $phase_code .= "\n" unless $requirements;
         $phase_code .= "};\n" unless $phase eq 'runtime';
 
         $code .= $phase_code . "\n" if $requirements or $include_empty;
@@ -106,7 +107,7 @@ use strict;
 
 my @bindings = qw(
     on requires recommends suggests conflicts
-    osname perl
+    osname
     configure_requires build_requires test_requires author_requires
 );
 
@@ -178,7 +179,6 @@ sub on {
 }
 
 sub osname { die "TODO" }
-sub perl { die "TODO" }
 
 sub requires {
     my($self, $module, $requirement) = @_;
@@ -336,6 +336,4 @@ Tatsuhiko Miyagawa
 
 L<cpanfile>, L<CPAN::Meta>, L<CPAN::Meta::Spec>
 
-=cut
-
-
+=cut
\ No newline at end of file
